attribute_env_vars_metadata

Attribute Macro attribute_env_vars_metadata 

#[attribute_env_vars_metadata]
Generates metadata for environment variables declared in the impl block.

This attribute macro should be applied to an impl EnvVars block. It will generate a metadata() method that returns all non-hidden environment variables with their documentation.